@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Java binding of Tokyo Cabinet
- *                                                      Copyright (C) 2006-2009 Mikio Hirabayashi
+ *                                                               Copyright (C) 2006-2010 FAL Labs
  * This file is part of Tokyo Cabinet.
  * Tokyo Cabinet is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -26,7 +26,8 @@ import java.net.*;
  * B+ tree database is a file containing a B+ tree and is handled with the B+ tree database API.
  * Before operations to store or retrieve records, it is necessary to open a database file and
  * connect the B+ tree database object to it.  To avoid data missing or corruption, it is
- * important to close every database file when it is no longer in use.
+ * important to close every database file when it is no longer in use.  It is forbidden for
+ * multible database objects in a process to open the same database at the same time.
  */
 public class BDB implements DBM {
   //----------------------------------------------------------------
@@ -120,11 +121,6 @@ public class BDB implements DBM {
   //----------------------------------------------------------------
   // public static methods
   //----------------------------------------------------------------
-  /**
-   * Get the string containing the version information.
-   * @return the string containing the version information.
-   */
-  public static native String version();
   /**
    * Get the message string corresponding to an error code.
    * @param ecode the error code.
@@ -204,7 +200,7 @@ public class BDB implements DBM {
    * default value is specified.  The default value is 32749.  Suggested size of the bucket array
    * is about from 1 to 4 times of the number of all pages to be stored.
    * @param apow the size of record alignment by power of 2.  If it is negative, the default
-   * value is specified.  The default value is 4 standing for 2^4=16.
+   * value is specified.  The default value is 8 standing for 2^8=256.
    * @param fpow the maximum number of elements of the free block pool by power of 2.  If it is
    * negative, the default value is specified.  The default value is 10 standing for 2^10=1024.
    * @param opts options by bitwise-or: `BDB.TLARGE' specifies that the size of the database can
@@ -230,10 +226,18 @@ public class BDB implements DBM {
    * Set the size of the extra mapped memory.
    * @param xmsiz the size of the extra mapped memory.  If it is not more than 0, the extra
    * mapped memory is disabled.  It is disabled by default.
-   * @return If successful, the return value is true, else, it is false.
+   * @return If successful, it is true, else, it is false.
    * @note The mapping parameters should be set before the database is opened.
    */
   public native boolean setxmsiz(long xmsiz);
+  /**
+   * Set the unit step number of auto defragmentation.
+   * @param dfunit the unit step number.  If it is not more than 0, the auto defragmentation is
+   * disabled.  It is disabled by default.
+   * @return If successful, it is true, else, it is false.
+   * @note The defragmentation parameters should be set before the database is opened.
+   */
+  public native boolean setdfunit(int dfunit);
   /**
    * Open a database file.
    * @param path the path of the database file.
@@ -394,12 +398,8 @@ public class BDB implements DBM {
    * @see #get(byte[])
    */
   public String get(String key){
-    try {
-      byte[] value = get(key.getBytes());
-      if(value != null) return new String(value, "UTF-8");
-    } catch(UnsupportedEncodingException e){
-    }
-    return null;
+    byte[] value = get(key.getBytes());
+    return value != null ? Util.otos(value) : null;
   }
   /**
    * Retrieve records.
@@ -414,18 +414,15 @@ public class BDB implements DBM {
    * @see #get(byte[])
    */
   public List getlist(String key){
-    try {
-      List values = getlist(key.getBytes());
-      if(values != null){
-        List svalues = new ArrayList();
-        Iterator it = values.iterator();
-        while(it.hasNext()){
-          byte[] value = (byte[])it.next();
-          svalues.add(new String(value, "UTF-8"));
-        }
-        return svalues;
+    List values = getlist(key.getBytes());
+    if(values != null){
+      List svalues = new ArrayList();
+      Iterator it = values.iterator();
+      while(it.hasNext()){
+        byte[] value = (byte[])it.next();
+        svalues.add(Util.otos(value));
       }
-    } catch(UnsupportedEncodingException e){
+      return svalues;
     }
     return null;
   }
@@ -495,8 +492,8 @@ public class BDB implements DBM {
    * @param einc whether the ending border is inclusive or not.
    * @param max the maximum number of keys to be fetched.  If it is negative, no limit is
    * specified.
-   * @return a list object of the keys of the corresponding records.  This method does never fail
-   * and return an empty list even if no record corresponds.
+   * @return a list object of the keys of the corresponding records.  This method does never fail.
+   * It returns an empty list even if no record corresponds.
    */
   public native List range(byte[] bkey, boolean binc, byte[] ekey, boolean einc, int max);
   /**
@@ -506,26 +503,22 @@ public class BDB implements DBM {
    * @see #range(byte[], boolean, byte[], boolean, int)
    */
   public List range(String bkey, boolean binc, String ekey, boolean einc, int max){
-    try {
-      List keys = range(bkey.getBytes(), binc, ekey.getBytes(), einc, max);
-      List skeys = new ArrayList();
-      Iterator it = keys.iterator();
-      while(it.hasNext()){
-        byte[] key = (byte[])it.next();
-        skeys.add(new String(key, "UTF-8"));
-      }
-      return skeys;
-    } catch(UnsupportedEncodingException e){
+    List keys = range(bkey.getBytes(), binc, ekey.getBytes(), einc, max);
+    List skeys = new ArrayList();
+    Iterator it = keys.iterator();
+    while(it.hasNext()){
+      byte[] key = (byte[])it.next();
+      skeys.add(Util.otos(key));
     }
-    return null;
+    return skeys;
   }
   /**
    * Get forward matching keys.
    * @param prefix the prefix of the corresponding keys.
    * @param max the maximum number of keys to be fetched.  If it is negative, no limit is
    * specified.
-   * @return a list object of the keys of the corresponding records.  This method does never fail
-   * and return an empty list even if no record corresponds.
+   * @return a list object of the keys of the corresponding records.  This method does never fail.
+   * It returns an empty list even if no record corresponds.
    */
   public native List fwmkeys(byte[] prefix, int max);
   /**
@@ -534,18 +527,14 @@ public class BDB implements DBM {
    * @see #fwmkeys(byte[], int)
    */
   public List fwmkeys(String prefix, int max){
-    try {
-      List keys = fwmkeys(prefix.getBytes(), max);
-      List skeys = new ArrayList();
-      Iterator it = keys.iterator();
-      while(it.hasNext()){
-        byte[] key = (byte[])it.next();
-        skeys.add(new String(key, "UTF-8"));
-      }
-      return skeys;
-    } catch(UnsupportedEncodingException e){
+    List keys = fwmkeys(prefix.getBytes(), max);
+    List skeys = new ArrayList();
+    Iterator it = keys.iterator();
+    while(it.hasNext()){
+      byte[] key = (byte[])it.next();
+      skeys.add(Util.otos(key));
     }
-    return null;
+    return skeys;
   }
   /**
    * Add an integer to a record.
