@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Java binding of Tokyo Cabinet
- *                                                      Copyright (C) 2006-2009 Mikio Hirabayashi
+ *                                                               Copyright (C) 2006-2010 FAL Labs
  * This file is part of Tokyo Cabinet.
  * Tokyo Cabinet is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -27,7 +27,8 @@ import java.net.*;
  * with the fixed-length database API.  Before operations to store or retrieve records, it is
  * necessary to open a database file and connect the fixed-length database object to it.  To
  * avoid data missing or corruption, it is important to close every database file when it is no
- * longer in use.
+ * longer in use.  It is forbidden for multible database objects in a process to open the same
+ * database at the same time.
  */
 public class FDB implements DBM {
   //----------------------------------------------------------------
@@ -103,11 +104,6 @@ public class FDB implements DBM {
   //----------------------------------------------------------------
   // public static methods
   //----------------------------------------------------------------
-  /**
-   * Get the string containing the version information.
-   * @return the string containing the version information.
-   */
-  public static native String version();
   /**
    * Get the message string corresponding to an error code.
    * @param ecode the error code.
@@ -284,12 +280,8 @@ public class FDB implements DBM {
    * @see #get(byte[])
    */
   public String get(String key){
-    try {
-      byte[] value = get(key.getBytes());
-      if(value != null) return new String(value, "UTF-8");
-    } catch(UnsupportedEncodingException e){
-    }
-    return null;
+    byte[] value = get(key.getBytes());
+    return value != null ? Util.otos(value) : null;
   }
   /**
    * Get the size of the value of a record.
@@ -329,20 +321,16 @@ public class FDB implements DBM {
    * @see #iternext()
    */
   public String iternext2(){
-    try {
-      byte[] key = iternext();
-      if(key != null) return new String(key, "UTF-8");
-    } catch(UnsupportedEncodingException e){
-    }
-    return null;
+    byte[] key = iternext();
+    return key != null ? Util.otos(key) : null;
   }
   /**
    * Get keys with an interval notation.
    * @param interval the interval notation.
    * @param max the maximum number of keys to be fetched.  If it is negative, no limit is
    * specified.
-   * @return a list object of the keys of the corresponding records.  This method does never fail
-   * and return an empty list even if no record corresponds.
+   * @return a list object of the keys of the corresponding records.  This method does never fail.
+   * It returns an empty list even if no record corresponds.
    */
   public native List range(byte[] interval, int max);
   /**
@@ -351,18 +339,14 @@ public class FDB implements DBM {
    * @see #range(byte[], int)
    */
   public List range(String interval, int max){
-    try {
-      List keys = range(interval.getBytes(), max);
-      List skeys = new ArrayList();
-      Iterator it = keys.iterator();
-      while(it.hasNext()){
-        byte[] key = (byte[])it.next();
-        skeys.add(new String(key, "UTF-8"));
-      }
-      return skeys;
-    } catch(UnsupportedEncodingException e){
+    List keys = range(interval.getBytes(), max);
+    List skeys = new ArrayList();
+    Iterator it = keys.iterator();
+    while(it.hasNext()){
+      byte[] key = (byte[])it.next();
+      skeys.add(Util.otos(key));
     }
-    return null;
+    return skeys;
   }
   /**
    * Get forward matching keys.
