@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Java binding of Tokyo Cabinet
- *                                                      Copyright (C) 2006-2009 Mikio Hirabayashi
+ *                                                               Copyright (C) 2006-2010 FAL Labs
  * This file is part of Tokyo Cabinet.
  * Tokyo Cabinet is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -26,7 +26,8 @@ import java.net.*;
  * Hash database is a file containing a hash table and is handled with the hash database API.
  * Before operations to store or retrieve records, it is necessary to open a database file and
  * connect the hash database object to it.  To avoid data missing or corruption, it is important
- * to close every database file when it is no longer in use.
+ * to close every database file when it is no longer in use.  It is forbidden for multible
+ * database objects in a process to open the same database at the same time.
  */
 public class HDB implements DBM {
   //----------------------------------------------------------------
@@ -112,11 +113,6 @@ public class HDB implements DBM {
   //----------------------------------------------------------------
   // public static methods
   //----------------------------------------------------------------
-  /**
-   * Get the string containing the version information.
-   * @return the string containing the version information.
-   */
-  public static native String version();
   /**
    * Get the message string corresponding to an error code.
    * @param ecode the error code.
@@ -195,10 +191,18 @@ public class HDB implements DBM {
    * Set the size of the extra mapped memory.
    * @param xmsiz the size of the extra mapped memory.  If it is not more than 0, the extra
    * mapped memory is disabled.  The default size is 67108864.
-   * @return If successful, the return value is true, else, it is false.
+   * @return If successful, it is true, else, it is false.
    * @note The mapping parameters should be set before the database is opened.
    */
   public native boolean setxmsiz(long xmsiz);
+  /**
+   * Set the unit step number of auto defragmentation.
+   * @param dfunit the unit step number.  If it is not more than 0, the auto defragmentation is
+   * disabled.  It is disabled by default.
+   * @return If successful, it is true, else, it is false.
+   * @note The defragmentation parameters should be set before the database is opened.
+   */
+  public native boolean setdfunit(int dfunit);
   /**
    * Open a database file.
    * @param path the path of the database file.
@@ -320,12 +324,8 @@ public class HDB implements DBM {
    * @see #get(byte[])
    */
   public String get(String key){
-    try {
-      byte[] value = get(key.getBytes());
-      if(value != null) return new String(value, "UTF-8");
-    } catch(UnsupportedEncodingException e){
-    }
-    return null;
+    byte[] value = get(key.getBytes());
+    return value != null ? Util.otos(value) : null;
   }
   /**
    * Get the size of the value of a record.
@@ -365,20 +365,16 @@ public class HDB implements DBM {
    * @see #iternext()
    */
   public String iternext2(){
-    try {
-      byte[] key = iternext();
-      if(key != null) return new String(key, "UTF-8");
-    } catch(UnsupportedEncodingException e){
-    }
-    return null;
+    byte[] key = iternext();
+    return key != null ? Util.otos(key) : null;
   }
   /**
    * Get forward matching keys.
    * @param prefix the prefix of the corresponding keys.
    * @param max the maximum number of keys to be fetched.  If it is negative, no limit is
    * specified.
-   * @return a list object of the keys of the corresponding records.  This method does never fail
-   * and return an empty list even if no record corresponds.
+   * @return a list object of the keys of the corresponding records.  This method does never fail.
+   * It returns an empty list even if no record corresponds.
    * @note This function may be very slow because every key in the database is scanned.
    */
   public native List fwmkeys(byte[] prefix, int max);
@@ -388,18 +384,14 @@ public class HDB implements DBM {
    * @see #fwmkeys(byte[], int)
    */
   public List fwmkeys(String prefix, int max){
-    try {
-      List keys = fwmkeys(prefix.getBytes(), max);
-      List skeys = new ArrayList();
-      Iterator it = keys.iterator();
-      while(it.hasNext()){
-        byte[] key = (byte[])it.next();
-        skeys.add(new String(key, "UTF-8"));
-      }
-      return skeys;
-    } catch(UnsupportedEncodingException e){
+    List keys = fwmkeys(prefix.getBytes(), max);
+    List skeys = new ArrayList();
+    Iterator it = keys.iterator();
+    while(it.hasNext()){
+      byte[] key = (byte[])it.next();
+      skeys.add(Util.otos(key));
     }
-    return null;
+    return skeys;
   }
   /**
    * Add an integer to a record.
