@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The test cases of the hash database API
- *                                                      Copyright (C) 2006-2009 Mikio Hirabayashi
+ *                                                               Copyright (C) 2006-2010 FAL Labs
  * This file is part of Tokyo Cabinet.
  * Tokyo Cabinet is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -352,6 +352,18 @@ class HDBTest {
       eprint(hdb, "tune");
       err = true;
     }
+    if(!hdb.setcache(rnum / 10)){
+      eprint(hdb, "setcache");
+      err = true;
+    }
+    if(!hdb.setxmsiz(rnum * 4)){
+      eprint(hdb, "setxmsiz");
+      err = true;
+    }
+    if(!hdb.setdfunit(8)){
+      eprint(hdb, "setdfunit");
+      err = true;
+    }
     if(!hdb.open(path, HDB.OWRITER | HDB.OCREAT | HDB.OTRUNC | omode)){
       eprint(hdb, "open");
       err = true;
