@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Java binding of Tokyo Cabinet
- *                                                      Copyright (C) 2006-2009 Mikio Hirabayashi
+ *                                                               Copyright (C) 2006-2010 FAL Labs
  * This file is part of Tokyo Cabinet.
  * Tokyo Cabinet is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -19,7 +19,7 @@
 
 typedef struct {
   JavaVM *vm;
-  jobject cmp;
+  jobject obj;
   jmethodID mid;
 } TCCMPOP;
 
@@ -39,18 +39,6 @@ static int tccmpobj(const char *aptr, int asiz, const char *bptr, int bsiz, TCCM
  *************************************************************************************************/
 
 
-/* version */
-JNIEXPORT jstring JNICALL Java_tokyocabinet_BDB_version
-(JNIEnv *env, jclass cls){
-  jstring jver = (*env)->NewStringUTF(env, tcversion);
-  if(!jver){
-    throwoutmem(env);
-    return NULL;
-  }
-  return jver;
-}
-
-
 /* ecode */
 JNIEXPORT jstring JNICALL Java_tokyocabinet_BDB_errmsg
 (JNIEnv *env, jclass cls, jint ecode){
@@ -89,7 +77,7 @@ JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_setcomparator
   TCBDB *bdb = (TCBDB *)(intptr_t)(*env)->GetLongField(env, self, bdb_fid_ptr);
   TCCMPOP *cmpop = tcbdbcmpop(bdb);
   if(cmpop){
-    (*env)->DeleteGlobalRef(env, cmpop->cmp);
+    (*env)->DeleteGlobalRef(env, cmpop->obj);
     tcfree(cmpop);
   }
   JavaVM *vm;
@@ -97,7 +85,7 @@ JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_setcomparator
   jclass clscmp = (*env)->GetObjectClass(env, cmp);
   cmpop = tcmalloc(sizeof(*cmpop));
   cmpop->vm = vm;
-  cmpop->cmp = (*env)->NewGlobalRef(env, cmp);
+  cmpop->obj = (*env)->NewGlobalRef(env, cmp);
   cmpop->mid = (*env)->GetMethodID(env, clscmp, "compare", "([B[B)I");
   return tcbdbsetcmpfunc(bdb, (TCCMP)tccmpobj, cmpop);
 }
@@ -109,7 +97,7 @@ JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_setcmpfunc
   TCBDB *bdb = (TCBDB *)(intptr_t)(*env)->GetLongField(env, self, bdb_fid_ptr);
   TCCMPOP *cmpop = tcbdbcmpop(bdb);
   if(cmpop){
-    (*env)->DeleteGlobalRef(env, cmpop->cmp);
+    (*env)->DeleteGlobalRef(env, cmpop->obj);
     tcfree(cmpop);
   }
   switch(cmp){
@@ -148,6 +136,14 @@ JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_setxmsiz
 }
 
 
+/* setdfunit */
+JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_setdfunit
+(JNIEnv *env, jobject self, jint dfunit){
+  TCBDB *bdb = (TCBDB *)(intptr_t)(*env)->GetLongField(env, self, bdb_fid_ptr);
+  return tcbdbsetdfunit(bdb, dfunit);
+}
+
+
 /* open */
 JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_open
 (JNIEnv *env, jobject self, jstring path, jint omode){
@@ -156,14 +152,14 @@ JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_open
     return false;
   }
   TCBDB *bdb = (TCBDB *)(intptr_t)(*env)->GetLongField(env, self, bdb_fid_ptr);
-  jboolean icpath;
-  const char *tpath = (*env)->GetStringUTFChars(env, path, &icpath);
+  jboolean icp;
+  const char *tpath = (*env)->GetStringUTFChars(env, path, &icp);
   if(!tpath){
     throwoutmem(env);
     return false;
   }
   bool rv = tcbdbopen(bdb, tpath, omode);
-  if(icpath) (*env)->ReleaseStringUTFChars(env, path, tpath);
+  if(icp) (*env)->ReleaseStringUTFChars(env, path, tpath);
   return rv;
 }
 
@@ -655,14 +651,14 @@ JNIEXPORT jboolean JNICALL Java_tokyocabinet_BDB_copy
     return false;
   }
   TCBDB *bdb = (TCBDB *)(intptr_t)(*env)->GetLongField(env, self, bdb_fid_ptr);
-  jboolean icpath;
-  const char *tpath = (*env)->GetStringUTFChars(env, path, &icpath);
+  jboolean icp;
+  const char *tpath = (*env)->GetStringUTFChars(env, path, &icp);
   if(!tpath){
     throwoutmem(env);
     return false;
   }
   bool rv = tcbdbcopy(bdb, tpath);
-  if(icpath) (*env)->ReleaseStringUTFChars(env, path, tpath);
+  if(icp) (*env)->ReleaseStringUTFChars(env, path, tpath);
   return rv;
 }
 
@@ -741,7 +737,7 @@ JNIEXPORT void JNICALL Java_tokyocabinet_BDB_destruct
   TCBDB *bdb = (TCBDB *)(intptr_t)(*env)->GetLongField(env, self, bdb_fid_ptr);
   TCCMPOP *cmpop = tcbdbcmpop(bdb);
   if(cmpop){
-    (*env)->DeleteGlobalRef(env, cmpop->cmp);
+    (*env)->DeleteGlobalRef(env, cmpop->obj);
     tcfree(cmpop);
   }
   tcbdbdel(bdb);
@@ -763,7 +759,7 @@ static int tccmpobj(const char *aptr, int asiz, const char *bptr, int bsiz, TCCM
   (*env)->SetByteArrayRegion(env, a, 0, asiz, (jbyte *)aptr);
   jbyteArray b = (*env)->NewByteArray(env, bsiz);
   (*env)->SetByteArrayRegion(env, b, 0, bsiz, (jbyte *)bptr);
-  int rv = (*env)->CallIntMethod(env, cmpop->cmp, cmpop->mid, a, b);
+  int rv = (*env)->CallIntMethod(env, cmpop->obj, cmpop->mid, a, b);
   if((*env)->ExceptionOccurred(env) != NULL){
     (*env)->ExceptionClear(env);
     rv = 0;
